import gevent
import logging
from grobot import GRobot

USERNAME = 'your twitter username'
PASSWORD = 'your twitter password'


def main():
    robot = GRobot(display=True, log_level=logging.DEBUG, develop=False)

    # Chinese people love proxy.
    robot.set_proxy('socks5://127.0.0.1:7070')

    robot.open('https://twitter.com')

    # Login
    robot.key_clicks('id=signin-email', USERNAME)
    robot.key_clicks('id=signin-password', PASSWORD)

    robot.click("xpath=//td/button[contains(text(),'Sign in')]", expect_loading=True)

    # Post a twitter
    robot.key_clicks("id=tweet-box-mini-home-profile", "GRobot is too powerful.https://github.com/DYFeng/GRobot")

    # Wait for post success
    while 1:
        robot.click("xpath=//div[@class='module mini-profile']//button[text()='Tweet']")
        try:
            robot.wait_for_text('Your Tweet was posted')
            break
        except:
            #Something go wrong,refresh page.
            if 'refresh the page' in robot.content:
                robot.reload()

    # Wait forever.
    robot.wait_forever()


if __name__ == '__main__':
    gevent.spawn(main).join()


import gevent
import logging
from grobot import GRobot


def main():
    # Show the browser window.Open the webkit inspector.
    robot = GRobot(display=True, develop=False, log_level=logging.DEBUG, loading_timeout=10, operate_timeout=10)

    # In China,people can only using proxy to access google.
    robot.set_proxy('socks5://127.0.0.1:7070')

    #Open google
    robot.open('http://www.google.com/')

    #Type out project and search.
    robot.type('name=q', 'GRobot github')
    robot.click('name=btnK', expect_loading=True)

    for i in xrange(1, 10):
        # Waiting for the ajax page loading.

        robot.wait_for_xpath("//tr/td[@class='cur' and text()='%s']" % i)

        if u'https://github.com/DYFeng/GRobot' in robot.content:
            print 'The porject in page', i
            break

        # Click the Next link.We don't use expect_loading.Because it's ajax loading,not page loading.
        robot.click("xpath=//span[text()='Next']")

    else:
        print "Can not found.Make a promotion for it."

    # Wait forever.
    robot.wait_forever()


if __name__ == '__main__':
    gevent.spawn(main).join()


import os
from app import app
import unittest


class AppTestCase(unittest.TestCase):

    def setUp(self):
        self.app = app.test_client()

    def tearDown(self):
        pass

    def testLogin(self):

if __name__ == '__main__':
    unittest.main()


# -*- coding: utf-8 -*-
import os

from flask import Flask, render_template, url_for, redirect, jsonify
from flask import request, abort, Response, flash
from flask import make_response

from werkzeug import Headers
from gevent.wsgi import WSGIServer

app = Flask(__name__)

app.debug=True

@app.route('/',methods=['GET','POST'])
def home():
    return render_template('home.html')




if __name__ == '__main__':
    http_server = WSGIServer(('', 5000), app)
    http_server.serve_forever()
    app.run(use_reloader=False, use_debugger=True)
